@@ -29,7 +29,7 @@
 #include <tqpixmap.h>
 
 #include <kdebug.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 
 #include "signalplotter.h"
 
@@ -77,7 +77,7 @@ SignalPlotter::SignalPlotter( TQWidget *parent, const char *name )
     mBackgroundColor = TQColor( 0x313031 );
 
     // Restore window size and position.
-    KConfig* config = new KConfig( "knemorc", false );
+    TDEConfig* config = new TDEConfig( "knemorc", false );
     if ( config->hasGroup( "Interface_" + mName ) )
     {
         config->setGroup( "Interface_" + mName );
@@ -100,7 +100,7 @@ SignalPlotter::~SignalPlotter()
         delete [] p;
 
     // Store window size and position.
-    KConfig* config = new KConfig( "knemorc", false );
+    TDEConfig* config = new TDEConfig( "knemorc", false );
     if ( config->hasGroup( "Interface_" + mName ) )
     {
         config->setGroup( "Interface_" + mName );
@@ -160,7 +160,7 @@ void SignalPlotter::addSample( const TQValueList<double>& sampleBuf )
 
   /* If the vertical lines are scrolling, increment the offset
    * so they move with the data. The vOffset / hScale confusion
-   * is because v refers toQt::Vertical Lines, and h to the horizontal
+   * is because v refers to Vertical Lines, and h to the horizontal
    * distance between the vertical lines. */
   if ( mVerticalLinesScroll ) {
     mVerticalLinesOffset = ( mVerticalLinesOffset + mHorizontalScale)
